@@ -4,5 +4,5 @@ from .site_handler import SiteHandler
 from .dir_handler import DirHandler
 from .mark_handler import MarkHandler
 from .s3_browser import S3Browser
-from .s3_static_files import S3StaticFiles
+from .static_files import StaticFiles
 from .access_control import LoginHandler, LogoutHandler
